@@ -23,19 +23,19 @@ namespace pcl
 
       template<typename U> void operator() ()
       {
-        const char* name = traits::name<PointT, U>::value;
+        const char* name = pcl::traits::name<PointT, U>::value;
         std::uint32_t name_length = strlen(name);
         stream_.next(name_length);
         if (name_length > 0)
           memcpy(stream_.advance(name_length), name, name_length);
 
-        std::uint32_t offset = traits::offset<PointT, U>::value;
+        std::uint32_t offset = pcl::traits::offset<PointT, U>::value;
         stream_.next(offset);
 
-        std::uint8_t datatype = traits::datatype<PointT, U>::value;
+        std::uint8_t datatype = pcl::traits::datatype<PointT, U>::value;
         stream_.next(datatype);
 
-        std::uint32_t count = traits::datatype<PointT, U>::size;
+        std::uint32_t count = pcl::traits::datatype<PointT, U>::size;
         stream_.next(count);
       }
 
@@ -49,7 +49,7 @@ namespace pcl
 
       template<typename U> void operator() ()
       {
-        std::uint32_t name_length = strlen(traits::name<PointT, U>::value);
+        std::uint32_t name_length = strlen(pcl::traits::name<PointT, U>::value);
         length += name_length + 13;
       }
 
@@ -164,7 +164,7 @@ namespace ros
         stream.next(row_step);
         uint32_t data_size = row_step * height;
         stream.next(data_size);
-        memcpy(stream.advance(data_size), &m.points[0], data_size);
+        memcpy(stream.advance(data_size), m.points.data(), data_size);
 
         uint8_t is_dense = m.is_dense;
         stream.next(is_dense);
@@ -203,7 +203,7 @@ namespace ros
         stream.next(data_size);
         assert(data_size == m.height * m.width * point_step);
         m.points.resize(m.height * m.width);
-        uint8_t* m_data = reinterpret_cast<uint8_t*>(&m.points[0]);
+        uint8_t* m_data = reinterpret_cast<uint8_t*>(m.points.data());
         // If the data layouts match, can copy a whole row in one memcpy
         if (mapping.size() == 1 &&
             mapping[0].serialized_offset == 0 &&
